/*
 * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
 * Copyright (C) $$Year-Rel$$ The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */

package jalview.io;

import jalview.api.AlignViewControllerGuiI;
import jalview.schemes.ColourSchemeI;

import java.io.IOException;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

public class HtmlFile extends AlignFile
{
  public static final String FILE_EXT = "html";

  public static final String FILE_DESC = "HTML";

  private ColourSchemeI colourScheme;

  private boolean showSeqFeatures;

  public HtmlFile()
  {
    super();
  }

  public HtmlFile(FileParse source) throws IOException
  {
    super(source);
  }

  public HtmlFile(String inFile, String type) throws IOException
  {
    super(inFile, type);
  }

  @Override
  public void parse() throws IOException
  {
    try
    {
      StringBuilder htmlData = new StringBuilder();
      String currentLine;
      while ((currentLine = nextLine()) != null)
      {
        htmlData.append(currentLine);
      }

      Document doc = Jsoup.parse(htmlData.toString());
      Element content = doc.getElementById("seqData");
      String alignmentJsonString = content.val();

      JSONFile jsonFile = new JSONFile().parse(alignmentJsonString);
      seqs = jsonFile.getSeqs();
      seqGroups = jsonFile.getSeqGroups();
      annotations = jsonFile.getAnnotations();
      showSeqFeatures = jsonFile.isShowSeqFeatures();
      colourScheme = jsonFile.getColourScheme();
    } catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  public void applySettingsToAlignFrame(AlignViewControllerGuiI af)
  {
    af.setShowSeqFeatures(isShowSeqFeatures());
    af.changeColour(getColourScheme());
    af.setMenusForViewport();
  }


  @Override
  public String print()
  {
    throw new UnsupportedOperationException(
            "Print method of HtmlFile is not supported!");
  }

  public boolean isShowSeqFeatures()
  {
    return showSeqFeatures;
  }

  public void setShowSeqFeatures(boolean showSeqFeatures)
  {
    this.showSeqFeatures = showSeqFeatures;
  }

  public ColourSchemeI getColourScheme()
  {
    return colourScheme;
  }

  public void setColourScheme(ColourSchemeI colourScheme)
  {
    this.colourScheme = colourScheme;
  }

}
